PyXMake Developer Guide: PyXMake.VTL.stm_make._BaseCommandRunner Class Reference

| PyXMake Developer Guide 1.0 PyXMake

Loading...
Searching...
No Matches
Public Member Functions | Public Attributes | Protected Member Functions | Static Protected Member Functions | List of all members
PyXMake.VTL.stm_make._BaseCommandRunner Class Reference
Inheritance diagram for PyXMake.VTL.stm_make._BaseCommandRunner:

## Public Member Functions
| run (self)

## Public Attributes
| verbose

## Protected Member Functions
| _create_command (self)
| _run_command (self, command)
| _perform_post_actions (self)

## Static Protected Member Functions
| _create_build_dir ()

## Detailed Description

    Base class for encapsulating command line commands.

Definition at line 73 of file stm_make.py.

## Member Function Documentation

## ◆ _create_build_dir()

PyXMake.VTL.stm_make._BaseCommandRunner._create_build_dir | ( |  | ) |
| staticprotected

Definition at line 84 of file stm_make.py.

## ◆ _create_command()

PyXMake.VTL.stm_make._BaseCommandRunner._create_command | ( |  | self | ) |
| protected

Definition at line 88 of file stm_make.py.

## ◆ _perform_post_actions()

PyXMake.VTL.stm_make._BaseCommandRunner._perform_post_actions | ( |  | self | ) |
| protected

Definition at line 96 of file stm_make.py.

## ◆ _run_command()

PyXMake.VTL.stm_make._BaseCommandRunner._run_command | ( |  | self,
|  |  | command )
| protected

Reimplemented in PyXMake.VTL.stm_make.pyx_app, PyXMake.VTL.stm_make.pyx_bundle, PyXMake.VTL.stm_make.pyx_custom, PyXMake.VTL.stm_make.pyx_doxygen, PyXMake.VTL.stm_make.pyx_f2py, PyXMake.VTL.stm_make.pyx_fortran, PyXMake.VTL.stm_make.pyx_pytest, and PyXMake.VTL.stm_make.pyx_sphinx.

Definition at line 91 of file stm_make.py.

## ◆ run()

PyXMake.VTL.stm_make._BaseCommandRunner.run | ( |  | self | ) |

Definition at line 77 of file stm_make.py.

## Member Data Documentation

## ◆ verbose

PyXMake.VTL.stm_make._BaseCommandRunner.verbose

Definition at line 92 of file stm_make.py.

The documentation for this class was generated from the following file:

- src/PyXMake/VTL/stm_make.py